# StrikeMark


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from src.client.generated.models.strike_mark import StrikeMark

# TODO update the JSON string below
json = "{}"
# create an instance of StrikeMark from a JSON string
strike_mark_instance = StrikeMark.from_json(json)
# print the JSON string representation of the object
print(StrikeMark.to_json())

# convert the object into a dict
strike_mark_dict = strike_mark_instance.to_dict()
# create an instance of StrikeMark from a dict
strike_mark_from_dict = StrikeMark.from_dict(strike_mark_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


